"""Top-level package for eBEL API client."""

from ebel_rest.core import connect

__author__ = """Christian Ebeling"""
__email__ = 'Christian.Ebeling@scai.fraunhofer.de'
__version__ = '1.0.2'
